summaryrefslogtreecommitdiff
path: root/nn/runtime/ModelBuilder.h
diff options
context:
space:
mode:
Diffstat (limited to 'nn/runtime/ModelBuilder.h')
-rw-r--r--nn/runtime/ModelBuilder.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/nn/runtime/ModelBuilder.h b/nn/runtime/ModelBuilder.h
index b6fcd5294..c474ea7e8 100644
--- a/nn/runtime/ModelBuilder.h
+++ b/nn/runtime/ModelBuilder.h
@@ -131,8 +131,9 @@ class ModelBuilder {
ExecutionPlan* plan) const;
private:
// TODO(b/132322449): move partitionTheWork, partitionTheWorkInternal,
// findBestDeviceForEachOperation, sortIntoRunOrder to CompilationBuilder?
// Populates bestDeviceForOperation
//
@@ -149,6 +150,7 @@ class ModelBuilder {
float getPerformance(uint32_t preference, const std::shared_ptr<Device> device) const;
float getPerformance(uint32_t preference, const std::shared_ptr<Device> device,
uint32_t operationIndex) const;
+ bool supportedByControlFlowInterpreter(uint32_t operationIndex) const;
int partitionTheWorkInternal(uint32_t sourceModelIndex,
const std::vector<std::shared_ptr<Device>>& devices,
@@ -187,10 +189,9 @@ class ModelBuilder {
std::vector<hal::Operand> mOperands;
// Is at least one of those operands an OEM operand?
bool mHasOEMOperand = false;
- // Specifies where to find the list of indexes identifying
- // the inputs and outputs of the model. The offset is into
- // the mOperandIndexes table.
+ // The indexes of input operands of the model.
std::vector<uint32_t> mInputIndexes;
+ // The indexes of output operands of the model.
std::vector<uint32_t> mOutputIndexes;
MemoryTracker mMemories;
@@ -131,8 +131,9 @@ class ModelBuilder {
ExecutionPlan* plan) const;
private:
- // TODO(b/132322449): move partitionTheWork, partitionTheWorkInternal,
- // findBestDeviceForEachOperation, sortIntoRunOrder to CompilationBuilder?
+ // TODO(b/132322449): move partitionTheWork, findBestDeviceForEachOperation,
+ // getPerformance, supportedByControlFlowInterpreter,
+ // partitionTheWorkInternal, sortIntoRunOrder to CompilationBuilder?
// Populates bestDeviceForOperation
//